==> GADMTools_3.5-1.tar.gz: GADMTools/man/isopleth.Rd <==
\name{isopleth}
\alias{isopleth}

\title{ Draw an isopleth on selected regions }

\description{
Drawing an isopleth (also known as heat maps) with GADMTools is straightforward. You just have to select your shape(s) file(s) with \emph{gadm.loadcountries}, load your data from a
csv file for example, and call the isoopleth function with the right arguments.
}
\usage{
isopleth(x, data, palette=NULL, title="", subtitle = "", caption = "")
}
\arguments{
  \item{x}{ \bold{Object} GADMWrapper }
  
  \item{data}{
\bold{data.frame} - data to plot
}
  
  \item{palette}{
  \bold{String} - An RColorBrewer palette name or a \bold{String vector} 
  vector of colors. Default \bold{NULL}.
}
  \item{title}{  \bold{String} - Plot title. Default is an empty string.}
  \item{subtitle}{  \bold{String} - Plot subtitle. Default is an empty string.}
  \item{caption}{  \bold{String} - Plot caption. Default is an empty string.}
}
\details{
----
}
\value{
    \bold{Object}  ggplot2
}
\references{
----
}
\author{
Jean Pierre Decorps <jp.decorps@epiconcept.fr>
}
\note{
----
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
----
}
\examples{
# library(GADMTools)
# library(sp)

# France = gadm.loadCountries("FRA", level=1, simplify=0.01)
# W <- read.csv2("wepi.csv")
# W$lieux_lat <- as.double(as.character(W$lieux_lat))
# W$lieux_long <- as.double(as.character(W$lieux_long))
# colnames(W)[1] <- "latitude"
# colnames(W)[2] <- "longitude"
# Region = subset(France, regions=c("Ile-de-France","Haute-Normandie"), level=1)
# isopleth(Region, W)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~documentation }
\keyword{ ~hplot }% __ONLY ONE__ keyword per line

==> GADMTools_3.7-2.tar.gz: GADMTools/man/isopleth.Rd <==
\name{isopleth}
\alias{isopleth}

\title{ Draw an isopleth on selected regions }

\description{
Drawing an isopleth (also known as heat maps) with GADMTools is straightforward. You just have to select your shape(s) file(s) with \emph{gadm_loadcountries}, load your data from a
csv file for example, and call the isoopleth function with the right arguments.
}
\usage{
isopleth(x, data, palette=NULL, title="", subtitle = "", caption = "")
}
\arguments{
  \item{x}{ \bold{Object} gadm_sp }
  
  \item{data}{\bold{data.frame} - data to plot}
  
  \item{palette}{
  \bold{String} - An RColorBrewer palette name or a \bold{String vector} 
  vector of colors. Default \bold{NULL}.
}
  \item{title}{  \bold{String} - Plot title. Default is an empty string.}
  \item{subtitle}{  \bold{String} - Plot subtitle. Default is an empty string.}
  \item{caption}{  \bold{String} - Plot caption. Default is an empty string.}
}

\value{
    \bold{Object}  ggplot2
}

\author{
Jean Pierre Decorps <jp.decorps@epiconcept.fr>
}

%% ~Make other sections like Warning with \section{Warning }{....} ~


\examples{
library(GADMTools)
data(Corsica)

longitude <- runif(6, min=8.74, max = 9.25)
latitude  <- runif(6, min=41.7, max = 42.6)
Cases <- runif(6, 25, 112)
DAT <- data.frame(longitude, latitude, Cases)

isopleth(Corsica, data = DAT, palette = "Blues")

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~documentation }
\keyword{ ~hplot }% __ONLY ONE__ keyword per line
